@@ -38,7 +38,7 @@ class HomeAssistantCog(commands.Cog):
         await context.response.send_message(f"Alarm is {choices}ing")
 
     @app_commands.command(name="taylor_swiftly")
-    @app_commands.choices(choices=get_functions(ha.TaylorSwiftly))
+    @app_commands.choices(choices=get_functions(ha.TaylorSwiftly()))
     @commands.has_role("Shiny")
     async def tesla(self, context: discord.Interaction, choices: str):
         taylor = ha.TaylorSwiftly()
