@@ -66,9 +66,11 @@ TRELLO_APIKEY = secret_file.get("trello_apiKey")
 TRELLO_OAUTH_TOKEN = secret_file.get("trello_oauth_token")
 OPENAI_API_KEY = secret_file.get("openai_api_key")
 PHONECHECK_API_KEY = secret_file.get("phonecheck_api_key")
-HOMEASSISTANT_API = {}
-for store_key, store_value in secret_file.get("homeassistant_api").items():
-    HOMEASSISTANT_API[store_key] = {key: value for key, value in store_value.items()}
+
+HOMEASSISTANT_API = {
+    store_key: {config_key: config_value for config_key, config_value in store_value.items()}
+    for store_key, store_value in secret_file.get("homeassistant_api").items()
+}
 
 RESPONSE_MESSAGES = [
     "Hi {name}, we are open 11-7 Tu-Sa.",
